@@ -6,7 +6,9 @@
     参数全部可直接原地修改
 """
 import palp
+from typing import Union
 from loguru import logger
+from palp.network.request import Request
 
 
 class SpiderMiddleware(palp.SpiderMiddleware):
@@ -17,7 +19,16 @@ class SpiderMiddleware(palp.SpiderMiddleware):
         :param spider:
         :return:
         """
-        pass
+
+    def spider_error(self, spider, exception: Exception) -> None:
+        """
+        spider 出错时的操作
+
+        :param spider:
+        :param exception: 错误的详细信息
+        :return:
+        """
+        logger.exception(exception)
 
     def spider_close(self, spider) -> None:
         """
@@ -26,18 +37,6 @@ class SpiderMiddleware(palp.SpiderMiddleware):
         :param spider:
         :return:
         """
-        pass
-
-    def spider_error(self, spider, exception_type: str, exception: str) -> None:
-        """
-        spider 出错时的操作
-
-        :param spider:
-        :param exception_type: 错误的类型
-        :param exception: 错误的详细信息
-        :return:
-        """
-        logger.error(exception)
 
 
 class RequestMiddleware(palp.RequestMiddleware):
@@ -49,30 +48,17 @@ class RequestMiddleware(palp.RequestMiddleware):
         :param request:
         :return:
         """
-        pass
 
-    def request_close(self, spider, request, response):
-        """
-        请求结束时的操作
-
-        :param spider:
-        :param request: 该参数可返回（用于放弃当前请求，并发起新请求）
-        :param response:
-        :return: [Request, None]
-        """
-        return
-
-    def request_error(self, spider, request, exception_type: str, exception: str):
+    def request_error(self, spider, request, exception: Exception) -> Union[Request, None]:
         """
         请求出错时的操作
 
         :param spider:
         :param request: 该参数可返回（用于放弃当前请求，并发起新请求）
-        :param exception_type: 错误的类型
         :param exception: 错误的详细信息
         :return: [Request, None]
         """
-        logger.error(exception)
+        logger.exception(exception)
 
         return
 
@@ -85,3 +71,14 @@ class RequestMiddleware(palp.RequestMiddleware):
         :return:
         """
         logger.warning(f"失败的请求：{request}")
+
+    def request_close(self, spider, request, response) -> Union[Request, None]:
+        """
+        请求结束时的操作
+
+        :param spider:
+        :param request: 该参数可返回（用于放弃当前请求，并发起新请求）
+        :param response:
+        :return: [Request, None]
+        """
+        return
